**********************************
Synapse
**********************************

The class ``Synapse`` is used to describe the behavior of a synapse (parameters, equations...).

Class Synapse
=================

.. autoclass:: ANNarchy.Synapse
    :members:
